compile_hw_property

Function compile_hw_property 

pub fn compile_hw_property(
    spec: &str,
    decls: &[HwSignalDecl],
    bound: u32,
) -> Result<TranslateResult, HwError>
Compile an English hardware property with signal declarations.

Takes an English specification and a list of signal declarations that map English proper nouns to SVA signal names. Produces a BoundedExpr with correctly-mapped signal variables.